pub struct LiveInterval {
pub start: usize,
pub end: usize,
pub size_bytes: usize,
}Expand description
The liveness interval (first-use to last-use) of a tensor.
Fields
start: usizeIndex of the first statement that uses this tensor.
end: usizeIndex of the last statement that uses this tensor.
size_bytes: usizeSize of the tensor in bytes.